@@ -2,6 +2,7 @@ from __future__ import annotations
 
 from dataclasses import dataclass
 
+from leeger.exception import DoesNotExistException
 from leeger.model.abstract.UniqueId import UniqueId
 from leeger.model.league.Team import Team
 from leeger.model.league.Week import Week
@@ -34,6 +35,24 @@ class Year(UniqueId, JSONSerializable):
         equal = equal and self.yearSettings == otherYear.yearSettings
         return equal
 
+    def getTeamByName(self, teamName: str) -> Team:
+        """
+        Returns the Team with the given team name.
+        """
+        for team in self.teams:
+            if team.name == teamName:
+                return team
+        raise DoesNotExistException(f"Year does not have a team with name '{teamName}'.")
+
+    def getWeekByWeekNumber(self, weekNumber: int) -> Week:
+        """
+        Returns the Week with the given week number.
+        """
+        for week in self.weeks:
+            if week.weekNumber == weekNumber:
+                return week
+        raise DoesNotExistException(f"Year does not have a week with week number {weekNumber}.")
+
     def toJson(self) -> dict:
         return {
             "id": self.id,
